diff --git a/.github/workflows/frontend.yaml b/.github/workflows/frontend.yaml
index 62a3a6c43e..d5c5b2ddac 100644
--- a/.github/workflows/frontend.yaml
+++ b/.github/workflows/frontend.yaml
@@ -8,7 +8,7 @@ name: Frontend
on:
push:
- branches-ignore: ["l10*", "dependabot/*", "backport/*"]
+ branches-ignore: ["l10*", "dependabot/**", "backport/**"]
pull_request:
branches-ignore: ["l10*"]
diff --git a/.github/workflows/import_export.yaml b/.github/workflows/import_export.yaml
index c251bab557..36f7f6d71d 100644
--- a/.github/workflows/import_export.yaml
+++ b/.github/workflows/import_export.yaml
@@ -7,7 +7,7 @@ name: Import / Export
on:
push:
- branches-ignore: ["l10*", "dependabot/*", "backport/*"]
+ branches-ignore: ["l10*", "dependabot/**", "backport/**"]
pull_request:
branches-ignore: ["l10*"]
diff --git a/.github/workflows/qc_checks.yaml b/.github/workflows/qc_checks.yaml
index 9dab7c79a1..e3fe43fbde 100644
--- a/.github/workflows/qc_checks.yaml
+++ b/.github/workflows/qc_checks.yaml
@@ -4,7 +4,7 @@ name: QC
on:
push:
- branches-ignore: ["l10*", "dependabot/*", "backport/*"]
+ branches-ignore: ["l10*", "dependabot/**", "backport/**"]
pull_request:
branches-ignore: ["l10*"]
diff --git a/src/frontend/lib/types/Settings.tsx b/src/frontend/lib/types/Settings.tsx
index 46e1b10abe..0c89b19883 100644
--- a/src/frontend/lib/types/Settings.tsx
+++ b/src/frontend/lib/types/Settings.tsx
@@ -57,4 +57,5 @@ export interface SettingsStateProps {
pathParams?: PathParams;
getSetting: (key: string, default_value?: string) => string; // Return a raw setting value
isSet: (key: string, default_value?: boolean) => boolean; // Check a "boolean" setting
+ getSettingLength: () => number;
}
diff --git a/src/frontend/package.json b/src/frontend/package.json
index 4ceefd58c5..318b3d0a66 100644
--- a/src/frontend/package.json
+++ b/src/frontend/package.json
@@ -108,10 +108,10 @@
"zustand": "^5.0.14"
},
"devDependencies": {
- "@babel/core": "^7.29.7",
- "@babel/preset-react": "^7.29.7",
- "@babel/preset-typescript": "^7.29.7",
- "@babel/runtime": "^7.29.7",
+ "@babel/core": "^8.0.1",
+ "@babel/preset-react": "^8.0.1",
+ "@babel/preset-typescript": "^8.0.1",
+ "@babel/runtime": "^8.0.0",
"@codecov/vite-plugin": "^2.0.1",
"@flakiness/playwright": "^1.13.0",
"@lingui/babel-plugin-lingui-macro": "^5.9.5",
@@ -126,7 +126,7 @@
"@types/react-router-dom": "^5.3.3",
"@types/react-window": "^1.8.8",
"@vanilla-extract/vite-plugin": "^5.2.2",
- "@vitejs/plugin-react": "^5.2.0",
+ "@vitejs/plugin-react": "^5",
"babel-plugin-macros": "^3.1.0",
"nyc": "^18.0.0",
"otpauth": "^9.5.1",
diff --git a/src/frontend/src/components/settings/SettingList.tsx b/src/frontend/src/components/settings/SettingList.tsx
index a0eb5ebd18..177f1b60c7 100644
--- a/src/frontend/src/components/settings/SettingList.tsx
+++ b/src/frontend/src/components/settings/SettingList.tsx
@@ -28,21 +28,34 @@ export function SettingList({
settingsState,
keys,
onChange,
- onLoaded
+ onLoaded,
+ doGet
}: Readonly<{
heading?: string;
settingsState: SettingsStateProps;
keys?: string[];
onChange?: () => void;
onLoaded?: (settings: SettingsStateProps) => void;
+ doGet?: boolean;
}>) {
useEffect(() => {
- if (settingsState.loaded) {
+ if (settingsState.loaded === true) {
// Call the onLoaded callback if provided
onLoaded?.(settingsState);
}
}, [settingsState.loaded, settingsState.settings]);
+ // get data if doGet is true to break memos leading to hidden group panels
+ useMemo(() => {
+ if (doGet && !settingsState.loaded) {
+ settingsState.fetchSettings().then((success) => {
+ if (success) {
+ onLoaded?.(settingsState);
+ }
+ });
+ }
+ }, [doGet, settingsState]);
+
const api = useApi();
const allKeys = useMemo(
@@ -226,9 +239,11 @@ export function GlobalSettingList({
export function PluginSettingList({
pluginKey,
+ doGet,
onLoaded
}: Readonly<{
pluginKey: string;
+ doGet?: boolean;
onLoaded?: (settings: SettingsStateProps) => void;
}>) {
const store = useMemo(
@@ -246,14 +261,22 @@ export function PluginSettingList({
pluginSettings.fetchSettings();
}, [pluginSettings.fetchSettings]);
- return ;
+ return (
+
+ );
}
export function PluginUserSettingList({
pluginKey,
+ doGet,
onLoaded
}: Readonly<{
pluginKey: string;
+ doGet?: boolean;
onLoaded?: (settings: SettingsStateProps) => void;
}>) {
const store = useMemo(
@@ -271,7 +294,13 @@ export function PluginUserSettingList({
pluginUserSettings.fetchSettings();
}, [pluginUserSettings.fetchSettings]);
- return ;
+ return (
+
+ );
}
export function MachineSettingList({
diff --git a/src/frontend/src/pages/Index/Settings/PluginSettingsGroup.tsx b/src/frontend/src/pages/Index/Settings/PluginSettingsGroup.tsx
index 5b07a0601b..03ec15b477 100644
--- a/src/frontend/src/pages/Index/Settings/PluginSettingsGroup.tsx
+++ b/src/frontend/src/pages/Index/Settings/PluginSettingsGroup.tsx
@@ -25,11 +25,13 @@ function PluginSettingGroupItem({
}) {
// Hide the accordion item if there are no settings for this plugin
const [count, setCount] = useState(0);
+ const [doGet, setDoGet] = useState(true);
// Callback once the plugin settings have been loaded
const onLoaded = useCallback(
(settings: SettingsStateProps) => {
- setCount(settings.settings?.length || 0);
+ setCount(settings.getSettingLength());
+ setDoGet(false);
},
[pluginKey]
);
@@ -50,11 +52,20 @@ function PluginSettingGroupItem({
)}
+
{global ? (
-
+
) : (
-
+
)}
diff --git a/src/frontend/src/states/SettingsStates.tsx b/src/frontend/src/states/SettingsStates.tsx
index 4eeecb3053..9ef99611ac 100644
--- a/src/frontend/src/states/SettingsStates.tsx
+++ b/src/frontend/src/states/SettingsStates.tsx
@@ -65,6 +65,9 @@ export const useGlobalSettingsState = create(
isSet: (key: string, default_value?: boolean) => {
const value = get().lookup[key] ?? default_value ?? 'false';
return isTrue(value);
+ },
+ getSettingLength: () => {
+ return Object.keys(get().lookup).length;
}
})
);
@@ -114,6 +117,9 @@ export const useUserSettingsState = create((set, get) => ({
isSet: (key: string, default_value?: boolean) => {
const value = get().lookup[key] ?? default_value ?? 'false';
return isTrue(value);
+ },
+ getSettingLength: () => {
+ return Object.keys(get().lookup).length;
}
}));
@@ -185,6 +191,9 @@ export const createPluginSettingsState = ({
isSet: (key: string, default_value?: boolean) => {
const value = get().lookup[key] ?? default_value ?? 'false';
return isTrue(value);
+ },
+ getSettingLength: () => {
+ return Object.keys(get().lookup).length;
}
}));
};
@@ -246,6 +255,9 @@ export const createMachineSettingsState = ({
isSet: (key: string, default_value?: boolean) => {
const value = get().lookup[key] ?? default_value ?? 'false';
return isTrue(value);
+ },
+ getSettingLength: () => {
+ return Object.keys(get().lookup).length;
}
}));
};
diff --git a/src/frontend/yarn.lock b/src/frontend/yarn.lock
index fbb2ec10ab..019e562213 100644
--- a/src/frontend/yarn.lock
+++ b/src/frontend/yarn.lock
@@ -60,12 +60,25 @@
js-tokens "^4.0.0"
picocolors "^1.1.1"
+"@babel/code-frame@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/code-frame/-/code-frame-8.0.0.tgz#f374ea9392011ffecf223805dd0d9315606e5bbf"
+ integrity sha512-dYYg153EyN2Ekbqw2zAsbd6/JR+9N2SEoC7YV2GyyqMM7x9bLDTjBD6XBhSMLH0wtIVyJj03jWNriQhaN+eoCw==
+ dependencies:
+ "@babel/helper-validator-identifier" "^8.0.0"
+ js-tokens "^10.0.0"
+
"@babel/compat-data@^7.29.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/compat-data/-/compat-data-7.29.7.tgz#6f0237f0f36d2e51c0570a636faed9d2d0efe629"
integrity sha512-locTkQyKvwIEgBzVrn8693ebc97F2U8ZHjbXwDXJ5Fn2TCpNwTlKcaKLkdHop5c/icOFE7qt7Q9JC5hnKNa6Gg==
-"@babel/core@^7.17.7", "@babel/core@^7.20.12", "@babel/core@^7.21.0", "@babel/core@^7.23.9", "@babel/core@^7.29.0", "@babel/core@^7.29.7":
+"@babel/compat-data@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/compat-data/-/compat-data-8.0.0.tgz#e780eb6052d8ceeaeadd3a6cd82dda470a945622"
+ integrity sha512-DOjnob/cXOUgDOozCDeq/aK2p5y8dUIVdf6tNhEV1HQRd6I8aQ4f4fbtHRVEvb6lP3BGomrKHiS8ICAASSVQSw==
+
+"@babel/core@^7.17.7", "@babel/core@^7.20.12", "@babel/core@^7.21.0", "@babel/core@^7.23.9", "@babel/core@^7.29.0":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/core/-/core-7.29.7.tgz#80c10b17248082968b57a857b91640971f2070f7"
integrity sha512-RgHBCvtjbOK2gXSNBNIkNoEc9qoVEtau3hj8gEqKQuL3HZAibKarWFEI3Lfm6EYKkLalOh8eSrj9b+ch9H/VBA==
@@ -86,6 +99,28 @@
json5 "^2.2.3"
semver "^6.3.1"
+"@babel/core@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/core/-/core-8.0.1.tgz#dcb133d3ddcfb2b5a6558da03bf240319da0b8c8"
+ integrity sha512-5FgxM4dLQpMJHSiVATk8foW263dVHQHBVpXYiimNECVWG01f4nFyEbQixeT6Mwvg7TayREJ2gpKl3o2RoMdnqw==
+ dependencies:
+ "@babel/code-frame" "^8.0.0"
+ "@babel/generator" "^8.0.0"
+ "@babel/helper-compilation-targets" "^8.0.0"
+ "@babel/helpers" "^8.0.0"
+ "@babel/parser" "^8.0.0"
+ "@babel/template" "^8.0.0"
+ "@babel/traverse" "^8.0.0"
+ "@babel/types" "^8.0.0"
+ "@types/gensync" "^1.0.5"
+ convert-source-map "^2.0.0"
+ empathic "^2.0.1"
+ gensync "^1.0.0-beta.2"
+ import-meta-resolve "^4.2.0"
+ json5 "^2.2.3"
+ obug "^2.1.1"
+ semver "^7.7.3"
+
"@babel/generator@^7.21.1", "@babel/generator@^7.29.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/generator/-/generator-7.29.7.tgz#cca0b8827e6bcf3ba176788e7f3b180ad6db2fa3"
@@ -97,12 +132,24 @@
"@jridgewell/trace-mapping" "^0.3.28"
jsesc "^3.0.2"
-"@babel/helper-annotate-as-pure@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/helper-annotate-as-pure/-/helper-annotate-as-pure-7.29.7.tgz#c70fe3c6ecbdc3fd2dd1b0f498428b88b82ce47f"
- integrity sha512-OoK6239jHPuSQOoS0kfTVKn0b/rVTk0seKq4Gd2UMLtmOVLjDC0ki3e+c90Trqv2gMfvJFqkiljrr568+qddiw==
+"@babel/generator@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/generator/-/generator-8.0.0.tgz#24b7b53a74fa8e74cc2377e054fecef4dcdada96"
+ integrity sha512-NT9NrVwJsbSV6Y2FSstWa71EETOnzrjkL5/wX3D2mYHtKM+qvqB1DvR4D0Setb/gDBsHzRICifwEWMO8CnTF6g==
dependencies:
- "@babel/types" "^7.29.7"
+ "@babel/parser" "^8.0.0"
+ "@babel/types" "^8.0.0"
+ "@jridgewell/gen-mapping" "^0.3.12"
+ "@jridgewell/trace-mapping" "^0.3.28"
+ "@types/jsesc" "^2.5.0"
+ jsesc "^3.0.2"
+
+"@babel/helper-annotate-as-pure@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/helper-annotate-as-pure/-/helper-annotate-as-pure-8.0.0.tgz#e094d0ea95f319cdc399fe25ec82e4b3dddb8461"
+ integrity sha512-NSpMkMsvvZqzThJ0p1B02cbtA2ObEyfBvq950bmNkyxsxvcxwhvvCB036rKhlEnuBBo30bOrk13u3FzlKSoRrw==
+ dependencies:
+ "@babel/types" "^8.0.0"
"@babel/helper-compilation-targets@^7.29.7":
version "7.29.7"
@@ -115,31 +162,47 @@
lru-cache "^5.1.1"
semver "^6.3.1"
-"@babel/helper-create-class-features-plugin@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/helper-create-class-features-plugin/-/helper-create-class-features-plugin-7.29.7.tgz#6eddf286f2ec418f740c91d60a83347c55838ddd"
- integrity sha512-IY3ZD9Tmooqr3TUhc3DUWxiuo8xx1DWLhd5M7hQ+ZWJamqM2BbalrBJb2MisSLoYorOj75U03qULCxQTY9r3hg==
+"@babel/helper-compilation-targets@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/helper-compilation-targets/-/helper-compilation-targets-8.0.0.tgz#63f230f427c9ea82323d829c935f6190d93b3736"
+ integrity sha512-JwculLABZvyPvyLBpwU/E/IbH2uM3mnxNtIJpxnIfb24y1PrdVxK5Dqjle4DpgqpGRnwgC7G8IkzPdSXZrO1Ew==
dependencies:
- "@babel/helper-annotate-as-pure" "^7.29.7"
- "@babel/helper-member-expression-to-functions" "^7.29.7"
- "@babel/helper-optimise-call-expression" "^7.29.7"
- "@babel/helper-replace-supers" "^7.29.7"
- "@babel/helper-skip-transparent-expression-wrappers" "^7.29.7"
- "@babel/traverse" "^7.29.7"
- semver "^6.3.1"
+ "@babel/compat-data" "^8.0.0"
+ "@babel/helper-validator-option" "^8.0.0"
+ browserslist "^4.24.0"
+ lru-cache "^11.0.0"
+ semver "^7.7.3"
+
+"@babel/helper-create-class-features-plugin@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/helper-create-class-features-plugin/-/helper-create-class-features-plugin-8.0.1.tgz#d8c5f55a3741a5f7d526bb4bfc361805601ef954"
+ integrity sha512-++t3ZktzlLmASAxIlxeXQK9Z2YwUafYGYcvGBFevqOqt16HozVHStUoQvWD09fzAZOb/uJGpUTBuGK41AJAuOA==
+ dependencies:
+ "@babel/helper-annotate-as-pure" "^8.0.0"
+ "@babel/helper-member-expression-to-functions" "^8.0.0"
+ "@babel/helper-optimise-call-expression" "^8.0.0"
+ "@babel/helper-replace-supers" "^8.0.1"
+ "@babel/helper-skip-transparent-expression-wrappers" "^8.0.0"
+ "@babel/traverse" "^8.0.0"
+ semver "^7.7.3"
"@babel/helper-globals@^7.29.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/helper-globals/-/helper-globals-7.29.7.tgz#f04a96fbd8473241b1079243f5b3f03a3010ab7b"
integrity sha512-3nQVUAtvkKH9zahfWgw96Jc/uFOmjACE1kQz82E2lqWmHBgjzbNlsC22nuQTfahmWeQtTq5nQ/4Nnd2A1wj4zA==
-"@babel/helper-member-expression-to-functions@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/helper-member-expression-to-functions/-/helper-member-expression-to-functions-7.29.7.tgz#8dbdb3ce0b5c487e1aec10e13c9a43a500814df8"
- integrity sha512-j+7JYmk1JYDtACIGj0QJqqWZjoUpMoEikQGADMaHgCMCSDqd2+P32rfcibUNrGOMWrlzK1WJBdxrB3JJQZwWtg==
+"@babel/helper-globals@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/helper-globals/-/helper-globals-8.0.0.tgz#c93789d6c1c2f1b65a97a07515c471a049559bf1"
+ integrity sha512-lLozHOM6sWWlxNo8CYqHy4MBZeTvHXNgVPBfPOGsjPKUzHC2Az9QwB6gxdQmpwHl6GlQtbGgS+lj5887guDiLw==
+
+"@babel/helper-member-expression-to-functions@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/helper-member-expression-to-functions/-/helper-member-expression-to-functions-8.0.0.tgz#c097e24f7aeb60ab08966ef6c2127fc8ee32449e"
+ integrity sha512-xkXrMbtk87Gk7+oKBVmBc6EORg/Qwx++AHESldmHkpvG8wgccdhJJFwrzqlF382Fk8wfXhJHWE/g/43QvEGNPQ==
dependencies:
- "@babel/traverse" "^7.29.7"
- "@babel/types" "^7.29.7"
+ "@babel/traverse" "^8.0.0"
+ "@babel/types" "^8.0.0"
"@babel/helper-module-imports@^7.16.7", "@babel/helper-module-imports@^7.29.7":
version "7.29.7"
@@ -149,6 +212,14 @@
"@babel/traverse" "^7.29.7"
"@babel/types" "^7.29.7"
+"@babel/helper-module-imports@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/helper-module-imports/-/helper-module-imports-8.0.0.tgz#b6b16c75f80616b545f72e842d8224b981fd41d5"
+ integrity sha512-NZ7mSS93o4ndX4KrbD7W8Sf3QT8Qe24PrnFyUcuOPDzK6faqDFKjY9RG7he7+I7FdiQ4llpnosFqzrXa+Vy3Ew==
+ dependencies:
+ "@babel/traverse" "^8.0.0"
+ "@babel/types" "^8.0.0"
+
"@babel/helper-module-transforms@^7.29.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/helper-module-transforms/-/helper-module-transforms-7.29.7.tgz#b062747a5997ba138637201328bbff77960574ae"
@@ -158,50 +229,79 @@
"@babel/helper-validator-identifier" "^7.29.7"
"@babel/traverse" "^7.29.7"
-"@babel/helper-optimise-call-expression@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/helper-optimise-call-expression/-/helper-optimise-call-expression-7.29.7.tgz#77b0b5b94f1997fa9d6e3125f445227b1faf9d85"
- integrity sha512-+kmGVjcT9RGYzoDwdwEqEvGgKe3BYq+O1iGzjFubaNgZHwYHP6lsF2Yghf4kEuv9BV7tYDZ913aBW9am6YKong==
+"@babel/helper-module-transforms@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/helper-module-transforms/-/helper-module-transforms-8.0.1.tgz#e8cf988892d7d8c774a9072dca0962f94b606bb6"
+ integrity sha512-UgAhl1kqiW5ciE0yCXqqvnb4H2n3IELJ7lIIQRezwDPilPEZX5i+Rvbja9MFTkwUn2biEiSMeV31aUzR4Lwakw==
dependencies:
- "@babel/types" "^7.29.7"
+ "@babel/helper-module-imports" "^8.0.0"
+ "@babel/helper-validator-identifier" "^8.0.0"
+ "@babel/traverse" "^8.0.0"
+
+"@babel/helper-optimise-call-expression@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/helper-optimise-call-expression/-/helper-optimise-call-expression-8.0.0.tgz#dc1118493494fbfc3bb24b490550673908a99b6c"
+ integrity sha512-3W6satvtPuCUkUx63S2jMoW9EQNYkADgs1HTfufmL7gCmAulHMKupA/12WNz4A0GMMFn/YnWWwqOT9IZrJHQjg==
+ dependencies:
+ "@babel/types" "^8.0.0"
"@babel/helper-plugin-utils@^7.29.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/helper-plugin-utils/-/helper-plugin-utils-7.29.7.tgz#c0a0766f1a13617d8a17407d7ab8f9d486225ea4"
integrity sha512-G7sHYigPY17oO5SYWnfD/0MTBwVR781S/JI643e/JhUYgVgWE/61SoW3NH9KWUKyKq5LVh3npif99Wkt6j86Jw==
-"@babel/helper-replace-supers@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/helper-replace-supers/-/helper-replace-supers-7.29.7.tgz#bc3c3964329043c79112e513c1b198f16589ac21"
- integrity sha512-atfGXWSeCiF4DnKZIfmJfQRkSw9b9gNNXR1kqKjbhG4pGYCOnkp8OcTB8E3NXjBu8NpheSnOeNKz8KT7UNFTmQ==
- dependencies:
- "@babel/helper-member-expression-to-functions" "^7.29.7"
- "@babel/helper-optimise-call-expression" "^7.29.7"
- "@babel/traverse" "^7.29.7"
+"@babel/helper-plugin-utils@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/helper-plugin-utils/-/helper-plugin-utils-8.0.1.tgz#d1c9d8ae225902c597deac8c79ace4227feac8af"
+ integrity sha512-3PKFgjTyPlhFhorfP+SjKQxLViIL++zWjFOO4hGriYU+Bsm983DxEM1JmDRJVWXV0O9npu+xXRqz7Pbd3mh70g==
-"@babel/helper-skip-transparent-expression-wrappers@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/helper-skip-transparent-expression-wrappers/-/helper-skip-transparent-expression-wrappers-7.29.7.tgz#50c95c7e4c4f54936cfa0116428edc559862d551"
- integrity sha512-brcMGQaVzIeUb+6/bs1Av0f8YuNNjKY2JyvfRCsFuFsdKccEQ5Ges2y74D74NZ1Rz8lKJ9ksJkfqwQFJ/iNEyQ==
+"@babel/helper-replace-supers@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/helper-replace-supers/-/helper-replace-supers-8.0.1.tgz#c9b23aba6b9aff16cacac135052e790cde8d7d5b"
+ integrity sha512-B1SZADIcy3tmH8CmWvj4SHi/oAPom4UL3uknTc2QRNsPVLFk/sPnZvQL/8kj7Y5omvjMqie0vklvs6XM4OLW5Q==
dependencies:
- "@babel/traverse" "^7.29.7"
- "@babel/types" "^7.29.7"
+ "@babel/helper-member-expression-to-functions" "^8.0.0"
+ "@babel/helper-optimise-call-expression" "^8.0.0"
+ "@babel/traverse" "^8.0.0"
+
+"@babel/helper-skip-transparent-expression-wrappers@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/helper-skip-transparent-expression-wrappers/-/helper-skip-transparent-expression-wrappers-8.0.0.tgz#27a6db3fb4ed17d2b32dbb69c4b30be346d8e8a6"
+ integrity sha512-xmCA9kP3IhySsqhzwIdWGlDN/1A4cCKNBO/uwZx/3YzmDoMePwno2Q5/Bq0q+tYaKbeF940YiKV/kaW8Mzvpjw==
+ dependencies:
+ "@babel/traverse" "^8.0.0"
+ "@babel/types" "^8.0.0"
"@babel/helper-string-parser@^7.29.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/helper-string-parser/-/helper-string-parser-7.29.7.tgz#7f0871d99824d23137d60f86fcf6130fd5a1b51f"
integrity sha512-Pb5ijPrZ89GDH8223L4UP8i6QApWxs04RbPQJTeWDV0/keR2E36MeKnyr6LYmUUvqRRI+Iv87SuF1W6ErINzYw==
+"@babel/helper-string-parser@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/helper-string-parser/-/helper-string-parser-8.0.0.tgz#4d47d9ad35d0f5bd7d202b348bf558328a347977"
+ integrity sha512-6mJgmFFFIIO82vvoLt9XtRC7/TkzXfts1t/SpRX4IHSzMgqoPYCWesVu1udUPUWioAE/2fcG6WuI8zrkE1gwrg==
+
"@babel/helper-validator-identifier@^7.29.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/helper-validator-identifier/-/helper-validator-identifier-7.29.7.tgz#bd87084ced0c796ec46bda492de6e83d29e89fc2"
integrity sha512-qehxGkRj55h/ff8EMaJ+cYhyaKlHIxqYDn682wQD7RNp9UujOQsHog2uS0r2vzr4pW+sXf90NeeayjcNaX3fFg==
+"@babel/helper-validator-identifier@^8.0.0":
+ version "8.0.2"
+ resolved "https://registry.yarnpkg.com/@babel/helper-validator-identifier/-/helper-validator-identifier-8.0.2.tgz#5527f2e24e5a9f4de7426dca448031749691bb6f"
+ integrity sha512-9Fr9QeyCAyi1BR1jKZ6uYQ24EIhQUx5ReHfQU7drOE+TPOb+w11/dsqLkMOT2U29OdCT71XajrOT8xDc1C7orA==
+
"@babel/helper-validator-option@^7.29.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/helper-validator-option/-/helper-validator-option-7.29.7.tgz#cf315be940213b354eb4abcc0bd01ebe3f73bc2a"
integrity sha512-N9ZErrD+yW5geCDtBqnOoxmR8+tNKiGuxKlDpuJxfsqpa2dFcexaziGAE/qoHLiDDreVNMupxGmSoNlyvsA3gw==
+"@babel/helper-validator-option@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/helper-validator-option/-/helper-validator-option-8.0.0.tgz#53307a6882254fa8d940017a701a8f7ec603a1a9"
+ integrity sha512-U4Dybxh4WESWHt5XhBeExi4DrY0/DNK1aHpQbsrQXCUbFHuMweT0TpLEWKvaraV2Y6fS+ZXunsZ8zIuZIgvF2Q==
+
"@babel/helpers@^7.29.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/helpers/-/helpers-7.29.7.tgz#45abfde7548997e34376c3e69feb475cffb4a607"
@@ -210,6 +310,14 @@
"@babel/template" "^7.29.7"
"@babel/types" "^7.29.7"
+"@babel/helpers@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/helpers/-/helpers-8.0.0.tgz#2c612d4b7fdbd5f1d2fa7321015e36b02d1a2d79"
+ integrity sha512-wfbi91pM3py96oIiJEz7qIpyXDytgr9zQC1HEWwlGNVRAEmItuU/0a41ZUKu1sJGyhhOIpc4t5vk4PYzt8wpsg==
+ dependencies:
+ "@babel/template" "^8.0.0"
+ "@babel/types" "^8.0.0"
+
"@babel/parser@^7.1.0", "@babel/parser@^7.20.7", "@babel/parser@^7.22.0", "@babel/parser@^7.23.9", "@babel/parser@^7.29.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/parser/-/parser-7.29.7.tgz#837b87387cbf5ec5530cb634b3c622f68edb9334"
@@ -217,41 +325,62 @@
dependencies:
"@babel/types" "^7.29.7"
-"@babel/plugin-syntax-jsx@^7.16.7", "@babel/plugin-syntax-jsx@^7.29.7":
+"@babel/parser@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/parser/-/parser-8.0.0.tgz#31f6860840277dc1c6d6f8b67bf74e0ccaa5df0a"
+ integrity sha512-aLxAE+imI9bCcyaPrUDjBv3uSkWieifjLe0kuFOZF0zli0L6GCsTmsePnTr55adbIAgYz2zhN1vnFimCBUYcRQ==
+ dependencies:
+ "@babel/types" "^8.0.0"
+
+"@babel/plugin-syntax-jsx@^7.16.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/plugin-syntax-jsx/-/plugin-syntax-jsx-7.29.7.tgz#622c16f9ad63782fe6e83dadc7e40330744b7f1e"
integrity sha512-TSu8+mHCoEaaCDEZ0I3+6mvTBYR4PCxQwf2z9/r5Tbztv6NaLR3B9thGTTxX2WGuGHJqRiAbKPeGTJ5XWXVg6A==
dependencies:
"@babel/helper-plugin-utils" "^7.29.7"
-"@babel/plugin-syntax-typescript@^7.16.7", "@babel/plugin-syntax-typescript@^7.23.3", "@babel/plugin-syntax-typescript@^7.29.7":
+"@babel/plugin-syntax-jsx@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/plugin-syntax-jsx/-/plugin-syntax-jsx-8.0.1.tgz#ab457699bd42e3071541fdc2dbade25049f2cc2f"
+ integrity sha512-n0jtCOxEovhU7METqSQjcZO9pX53nu9uNIjMS+hEt+Nt9jA7oOZoBIgbCxhhASmF6T6rPDGge5UAvh6Z4eFz/g==
+ dependencies:
+ "@babel/helper-plugin-utils" "^8.0.1"
+
+"@babel/plugin-syntax-typescript@^7.16.7", "@babel/plugin-syntax-typescript@^7.23.3":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/plugin-syntax-typescript/-/plugin-syntax-typescript-7.29.7.tgz#7c29388932313ed58413a0343048d75d92fb5b24"
integrity sha512-ngr+82Sh0xMz25TPCZi+nC2iTzjfCdWS2ONXTp/PtSCHCgaCNBpdMqgvJ2ccdLlClVZ7sisIgB914j/JFe+RZA==
dependencies:
"@babel/helper-plugin-utils" "^7.29.7"
-"@babel/plugin-transform-modules-commonjs@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/plugin-transform-modules-commonjs/-/plugin-transform-modules-commonjs-7.29.7.tgz#70e6835abf2663dafbe94b8ef1f51de7351ef135"
- integrity sha512-j0vCldybPC5b5dwCQOJ21uKtHzt7hxLygJTg9eF1ScfaikEDNfzn94XoW5Fi+seBR0nCyL23xaBFFkq7dTM8XQ==
+"@babel/plugin-syntax-typescript@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/plugin-syntax-typescript/-/plugin-syntax-typescript-8.0.1.tgz#c02d0096b297bdd4dbd32b63dbac44c0f195b82f"
+ integrity sha512-YBpIeuOZSUZx7RGH/U+dIAsHDHyojBVDRHNBUgOiUDS5IIcgBm1uyu9xs/2kM27B/bmDfOxzJ9k8cU2QuOwGIA==
dependencies:
- "@babel/helper-module-transforms" "^7.29.7"
- "@babel/helper-plugin-utils" "^7.29.7"
+ "@babel/helper-plugin-utils" "^8.0.1"
-"@babel/plugin-transform-react-display-name@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/plugin-transform-react-display-name/-/plugin-transform-react-display-name-7.29.7.tgz#bf161a6d750267b79db7ff6f8fb89c3369b02df3"
- integrity sha512-+1wdDMGNb4UPeY3Q4L5yLiYe6TXPXubs4NjrgRFw13hPRLJfEMw2Q5OXkee6/IfdqePIeW4Jjwe3aBh7SdKz4Q==
+"@babel/plugin-transform-modules-commonjs@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/plugin-transform-modules-commonjs/-/plugin-transform-modules-commonjs-8.0.1.tgz#ae8c414da671dc7ac4bb4b502a2714841ab84402"
+ integrity sha512-PMuzulWrrzFNmY3lXSk/tV9NRb7y0eZZLJY4UEo2TKszroxvUZHAPPi+T9FDyrQhod+TQA+t+8/QYaaMpiEuhA==
dependencies:
- "@babel/helper-plugin-utils" "^7.29.7"
+ "@babel/helper-module-transforms" "^8.0.1"
+ "@babel/helper-plugin-utils" "^8.0.1"
-"@babel/plugin-transform-react-jsx-development@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/plugin-transform-react-jsx-development/-/plugin-transform-react-jsx-development-7.29.7.tgz#64e6aacb5cb43b9e80d3d5f19ddefc158a624f09"
- integrity sha512-Xfy3UVMF04+ypnFbkhvfqtmvwfe92qwQdbGZVonhE+6v35GzlofmOnA1szaZqzb9xYWr0nl1e5EMmzi0DNON1g==
+"@babel/plugin-transform-react-display-name@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/plugin-transform-react-display-name/-/plugin-transform-react-display-name-8.0.1.tgz#da70220bacd0abcfb3a5fa4af89acde94d891fbc"
+ integrity sha512-soLishXlkyu6jcICPyO3HEP7A3GCzKEnn7XfvYrImuWEOwFAz93qShmWSYPf5ww0ZkO4By0zsN2bVIDF54fSdA==
dependencies:
- "@babel/plugin-transform-react-jsx" "^7.29.7"
+ "@babel/helper-plugin-utils" "^8.0.1"
+
+"@babel/plugin-transform-react-jsx-development@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/plugin-transform-react-jsx-development/-/plugin-transform-react-jsx-development-8.0.1.tgz#11fa2b7af26ceaafc47a3cc6e2bd720bba96fc04"
+ integrity sha512-Hb+HUZpV9KFHjm+F+P3aLDMi8QXU9l3ROCQv20z18Me2sGyW5nNNR5YTevNlgHvCpFek3BnAwhDGq/BRndXViw==
+ dependencies:
+ "@babel/plugin-transform-react-jsx" "^8.0.1"
"@babel/plugin-transform-react-jsx-self@^7.27.1":
version "7.29.7"
@@ -267,64 +396,68 @@
dependencies:
"@babel/helper-plugin-utils" "^7.29.7"
-"@babel/plugin-transform-react-jsx@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/plugin-transform-react-jsx/-/plugin-transform-react-jsx-7.29.7.tgz#3d16a0e5773f079400a8c82a190709cdf92ee204"
- integrity sha512-WsZulLVBUHXVj2cUcPVx6UE21TpalB6bHbSFErKT0Ib++ax24jjXe73FqlWvdylFOjiuPHYi6VCcgRad1ItN+A==
+"@babel/plugin-transform-react-jsx@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/plugin-transform-react-jsx/-/plugin-transform-react-jsx-8.0.1.tgz#0b7192bd35e5ca68d1324cd9347f5990f296177f"
+ integrity sha512-NgkoF7Uq+30TmOPDdNUimT0Nta02uVjqJRFNlVWKrbOCu/CkzfHa4aMnIs0lMpkMmZmWA1e42Va+F04i/pY1zw==
dependencies:
- "@babel/helper-annotate-as-pure" "^7.29.7"
- "@babel/helper-module-imports" "^7.29.7"
- "@babel/helper-plugin-utils" "^7.29.7"
- "@babel/plugin-syntax-jsx" "^7.29.7"
- "@babel/types" "^7.29.7"
+ "@babel/helper-annotate-as-pure" "^8.0.0"
+ "@babel/helper-module-imports" "^8.0.0"
+ "@babel/helper-plugin-utils" "^8.0.1"
+ "@babel/plugin-syntax-jsx" "^8.0.1"
+ "@babel/types" "^8.0.0"
-"@babel/plugin-transform-react-pure-annotations@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/plugin-transform-react-pure-annotations/-/plugin-transform-react-pure-annotations-7.29.7.tgz#76445c90112dd0a7371b63264563bfa9a4fcd6e3"
- integrity sha512-H5E+HBgDpr6Q5t+Aj11tL7XkIui1jhbIoArVQnqjgXo5/3YxkN7ZEBcWF4RQlB0T4rrxJQbXS6kiFV6B7XTqUA==
+"@babel/plugin-transform-react-pure-annotations@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/plugin-transform-react-pure-annotations/-/plugin-transform-react-pure-annotations-8.0.1.tgz#95d5bf8dab5ce0631b320b75ce3c6a6e550c356a"
+ integrity sha512-7/8UwU8hoPBurXa9tUiTTC8aACTRy5tCqLUtqikHp2eGiWoEB57AduOdbQ71OOMTEvawKrGhv3WfzkDpI+/oSg==
dependencies:
- "@babel/helper-annotate-as-pure" "^7.29.7"
- "@babel/helper-plugin-utils" "^7.29.7"
+ "@babel/helper-annotate-as-pure" "^8.0.0"
+ "@babel/helper-plugin-utils" "^8.0.1"
-"@babel/plugin-transform-typescript@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/plugin-transform-typescript/-/plugin-transform-typescript-7.29.7.tgz#f0449c3df7037bbe232043476851c38f5e4a7615"
- integrity sha512-jK52h8LaLc7JarhQV2ofeFMts4H7vnOXnqZNA6fYglBTZewRBE51KWt3BUltW1P+KoPsYkHoJeXePuz4zo2LMw==
+"@babel/plugin-transform-typescript@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/plugin-transform-typescript/-/plugin-transform-typescript-8.0.1.tgz#805b11cae5334b4346640286950003c897f24b72"
+ integrity sha512-0Svqp3413Eg0GElldykF/T7SNsxQO5YVGD70fZyAdZTnX8WRgcopmbiU7GTa5xY5ZnJcEpNbfns8/GjX+/1yeA==
dependencies:
- "@babel/helper-annotate-as-pure" "^7.29.7"
- "@babel/helper-create-class-features-plugin" "^7.29.7"
- "@babel/helper-plugin-utils" "^7.29.7"
- "@babel/helper-skip-transparent-expression-wrappers" "^7.29.7"
- "@babel/plugin-syntax-typescript" "^7.29.7"
+ "@babel/helper-annotate-as-pure" "^8.0.0"
+ "@babel/helper-create-class-features-plugin" "^8.0.1"
+ "@babel/helper-plugin-utils" "^8.0.1"
+ "@babel/helper-skip-transparent-expression-wrappers" "^8.0.0"
+ "@babel/plugin-syntax-typescript" "^8.0.1"
-"@babel/preset-react@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/preset-react/-/preset-react-7.29.7.tgz#2ed18366e38c2081bbf1760dc01e88fa5674eb17"
- integrity sha512-C+PV1TFUPTmBQGoPBL8j2QmLpZ117YTCwxIZeJOM96GbYMFSc7/pOXU5lVykwnZxyTqQxRsvoRk6f2FktZgGHA==
+"@babel/preset-react@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/preset-react/-/preset-react-8.0.1.tgz#0cb1802ff37a96faf983b5e781270f2752bb3476"
+ integrity sha512-jrFuPp/pTddFZbtmWhdLNAYc6UMcpboeUPnw0BBrm4nOmcAko/1TRcFi1PzWCeOFRU+VaSiKmat87W1HvR7mIg==
dependencies:
- "@babel/helper-plugin-utils" "^7.29.7"
- "@babel/helper-validator-option" "^7.29.7"
- "@babel/plugin-transform-react-display-name" "^7.29.7"
- "@babel/plugin-transform-react-jsx" "^7.29.7"
- "@babel/plugin-transform-react-jsx-development" "^7.29.7"
- "@babel/plugin-transform-react-pure-annotations" "^7.29.7"
+ "@babel/helper-plugin-utils" "^8.0.1"
+ "@babel/helper-validator-option" "^8.0.0"
+ "@babel/plugin-transform-react-display-name" "^8.0.1"
+ "@babel/plugin-transform-react-jsx" "^8.0.1"
+ "@babel/plugin-transform-react-jsx-development" "^8.0.1"
+ "@babel/plugin-transform-react-pure-annotations" "^8.0.1"
-"@babel/preset-typescript@^7.29.7":
- version "7.29.7"
- resolved "https://registry.yarnpkg.com/@babel/preset-typescript/-/preset-typescript-7.29.7.tgz#de9be1f47b785c979ec7b3a71f4cd8bae5267b62"
- integrity sha512-/Foi8vKY2EVbed/1eZx0gJEEwHAIxogrySI7rULcRIvhZzbvoE/b5qG5Ghc0WKAFKOHA9SD1x7RsFlOYdutIiQ==
+"@babel/preset-typescript@^8.0.1":
+ version "8.0.1"
+ resolved "https://registry.yarnpkg.com/@babel/preset-typescript/-/preset-typescript-8.0.1.tgz#603e709db117e5fafef296de087e8a0a7679a543"
+ integrity sha512-qrPhQIN1NLrPmzgazF9XKQqXrOcp/WJly+K+6ReFonn24FZqRJO7clxOJo6Ni75L+2vAqI3cHVU2OJLBxoPp5A==
dependencies:
- "@babel/helper-plugin-utils" "^7.29.7"
- "@babel/helper-validator-option" "^7.29.7"
- "@babel/plugin-syntax-jsx" "^7.29.7"
- "@babel/plugin-transform-modules-commonjs" "^7.29.7"
- "@babel/plugin-transform-typescript" "^7.29.7"
+ "@babel/helper-plugin-utils" "^8.0.1"
+ "@babel/helper-validator-option" "^8.0.0"
+ "@babel/plugin-transform-modules-commonjs" "^8.0.1"
+ "@babel/plugin-transform-typescript" "^8.0.1"
-"@babel/runtime@^7.0.0", "@babel/runtime@^7.12.0", "@babel/runtime@^7.12.5", "@babel/runtime@^7.18.3", "@babel/runtime@^7.18.6", "@babel/runtime@^7.20.13", "@babel/runtime@^7.21.0", "@babel/runtime@^7.29.7", "@babel/runtime@^7.5.5", "@babel/runtime@^7.8.7":
+"@babel/runtime@^7.0.0", "@babel/runtime@^7.12.0", "@babel/runtime@^7.12.5", "@babel/runtime@^7.18.3", "@babel/runtime@^7.18.6", "@babel/runtime@^7.20.13", "@babel/runtime@^7.21.0", "@babel/runtime@^7.5.5", "@babel/runtime@^7.8.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/runtime/-/runtime-7.29.7.tgz#12022450c45a4da6d8d8287b18a4ff2ddb23f768"
integrity sha512-Nq8OhGWiZIZGV6hLHoyAKLLcJihP/xFeBMGJoUrxTX2psI8dCifzLhZISFb+VWS3wFMRDmCGw5R+dOySCqPLhw==
+"@babel/runtime@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/runtime/-/runtime-8.0.0.tgz#d7bd513e6843662346552c2798ab895716cf97f2"
+ integrity sha512-sL6cvO2IfkSu/iU+zs2S/w01B7A8V7suXSIKEN4hPFFdZoiPGxrj5pAG0lCaqLWiEIrjKzdznIWuaLcxPR53qw==
+
"@babel/template@^7.29.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/template/-/template-7.29.7.tgz#4d9d4004f645cdd304de958c725162784ecac700"
@@ -334,6 +467,15 @@
"@babel/parser" "^7.29.7"
"@babel/types" "^7.29.7"
+"@babel/template@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/template/-/template-8.0.0.tgz#18c12626b0d6d23a0443771655864ed7566a3452"
+ integrity sha512-eAD0QW/AlbamBbw0FeGiwasbCVPq5ncW0HNVyLP3B9czqLyh4gvw+5JTSNt6le9+ziAU7mqDZsKTHf3jTb4chQ==
+ dependencies:
+ "@babel/code-frame" "^8.0.0"
+ "@babel/parser" "^8.0.0"
+ "@babel/types" "^8.0.0"
+
"@babel/traverse@^7.29.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/traverse/-/traverse-7.29.7.tgz#c47b07a41b95da0907d026b5dd894d98de7d2f2d"
@@ -347,6 +489,19 @@
"@babel/types" "^7.29.7"
debug "^4.3.1"
+"@babel/traverse@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/traverse/-/traverse-8.0.0.tgz#0473589140c796d13e27641ab0783069f0fe7512"
+ integrity sha512-bxTj/W2VclGE6CctlfQOpxg8MPDzXArRqkOBePw8EHfebcjF7fETWSS3BriEECo+UiU/Yblq+xUtSImFu7cTbw==
+ dependencies:
+ "@babel/code-frame" "^8.0.0"
+ "@babel/generator" "^8.0.0"
+ "@babel/helper-globals" "^8.0.0"
+ "@babel/parser" "^8.0.0"
+ "@babel/template" "^8.0.0"
+ "@babel/types" "^8.0.0"
+ obug "^2.1.1"
+
"@babel/types@^7.0.0", "@babel/types@^7.20.7", "@babel/types@^7.21.2", "@babel/types@^7.28.2", "@babel/types@^7.29.7":
version "7.29.7"
resolved "https://registry.yarnpkg.com/@babel/types/-/types-7.29.7.tgz#8005e31d82712ee7adaef6e23c63b71a62770a92"
@@ -355,6 +510,14 @@
"@babel/helper-string-parser" "^7.29.7"
"@babel/helper-validator-identifier" "^7.29.7"
+"@babel/types@^8.0.0":
+ version "8.0.0"
+ resolved "https://registry.yarnpkg.com/@babel/types/-/types-8.0.0.tgz#b518f1ef7f9838bffdca4e123b449d3f644f4494"
+ integrity sha512-K8ponJDxBwDHigkeFqaqT5wLGl4bTlwMafR8k7b5CPxr6Ww+UG9ls8Yx6Tcpboxu97eeGVEEyKcHmEyOwN1vSw==
+ dependencies:
+ "@babel/helper-string-parser" "^8.0.0"
+ "@babel/helper-validator-identifier" "^8.0.0"
+
"@codecov/bundler-plugin-core@^2.0.1":
version "2.0.1"
resolved "https://registry.yarnpkg.com/@codecov/bundler-plugin-core/-/bundler-plugin-core-2.0.1.tgz#bdbeb575339a25b330178154eee6df9dcb01f31e"
@@ -470,9 +633,9 @@
crelt "^1.0.5"
"@codemirror/search@^6.0.0", "@codemirror/search@^6.6.0":
- version "6.7.0"
- resolved "https://registry.yarnpkg.com/@codemirror/search/-/search-6.7.0.tgz#c6bea0ab0e882395d03a760b1a7d3959b1f3a4ac"
- integrity sha512-ZvGm99wc/s2cITtMT15LFdn8aH/aS+V+DqyGq/N5ZlV5vWtH+nILvC2nw0zX7ByNoHHDZ2IxxdW38O0tc5nVHg==
+ version "6.7.1"
+ resolved "https://registry.yarnpkg.com/@codemirror/search/-/search-6.7.1.tgz#2523a762871d18ad982edc2d4b2fa1da483b0392"
+ integrity sha512-uMe5UO6PamJtSHrXhhHOzSX3ReWtiJrva6GnPMwSOrZtiExb5X5eExhr2OUZQVvdxPsKpY3Ro2mFbQadpPWmHA==
dependencies:
"@codemirror/state" "^6.0.0"
"@codemirror/view" "^6.37.0"
@@ -803,26 +966,26 @@
integrity sha512-wGnAPhfzivDwBWYmEG8MSrEXPruoiMMo48NnsRkj1NZkoaawgOijPNAiSHKMYEoCsqTBSgLTzL6EqTTWGaUR4w==
"@fullcalendar/core@^6.1.20":
- version "6.1.20"
- resolved "https://registry.yarnpkg.com/@fullcalendar/core/-/core-6.1.20.tgz#e4cfa767a9b8b7dad015b33fcb8acb0fac986a85"
- integrity sha512-1cukXLlePFiJ8YKXn/4tMKsy0etxYLCkXk8nUCFi11nRONF2Ba2CD5b21/ovtOO2tL6afTJfwmc1ed3HG7eB1g==
+ version "6.1.21"
+ resolved "https://registry.yarnpkg.com/@fullcalendar/core/-/core-6.1.21.tgz#e8b0ed592a60aba44499802fefdbb1fcc91b0a07"
+ integrity sha512-t3u/+sqh3Iq7TWtUnVLcGDUE6OWZh0UD3c04bI/l7lSLAgAKr3kngBmhHiQD1QXpwC8ZN5iNqG7a7gOVixhSKQ==
dependencies:
preact "~10.12.1"
"@fullcalendar/daygrid@^6.1.20":
- version "6.1.20"
- resolved "https://registry.yarnpkg.com/@fullcalendar/daygrid/-/daygrid-6.1.20.tgz#fcf33af4ea908b46fd755414278341811e01bdf8"
- integrity sha512-AO9vqhkLP77EesmJzuU+IGXgxNulsA8mgQHynclJ8U70vSwAVnbcLG9qftiTAFSlZjiY/NvhE7sflve6cJelyQ==
+ version "6.1.21"
+ resolved "https://registry.yarnpkg.com/@fullcalendar/daygrid/-/daygrid-6.1.21.tgz#70eef7af5951b35a5f0380b15e32e5389ae029bc"
+ integrity sha512-QYb1y40RGYLlOxKpYWg8O+7njEnKnFG8Tt7qjnubJGR35s1phQg67E+81y2TyAbbm59p2JFOCXGDk9t6KDujIA==
"@fullcalendar/interaction@^6.1.20":
- version "6.1.20"
- resolved "https://registry.yarnpkg.com/@fullcalendar/interaction/-/interaction-6.1.20.tgz#a73a53af5f93ac261f864b025ae80201609f1cd7"
- integrity sha512-p6txmc5txL0bMiPaJxe2ip6o0T384TyoD2KGdsU6UjZ5yoBlaY+dg7kxfnYKpYMzEJLG58n+URrHr2PgNL2fyA==
+ version "6.1.21"
+ resolved "https://registry.yarnpkg.com/@fullcalendar/interaction/-/interaction-6.1.21.tgz#e7fd36d7d328a02e1d7a1dcc174db7650a6edf31"
+ integrity sha512-WPYpqtljDWmU0Xm2cOtFrLlocgxv7cgkOppj34Q6OUUat8a6Cnd6kYo2JR+irP223PE5lBYHFNp1qh7SIpJc0w==
"@fullcalendar/react@^6.1.20":
- version "6.1.20"
- resolved "https://registry.yarnpkg.com/@fullcalendar/react/-/react-6.1.20.tgz#7f2a8ede416364ab3b426c8e7c6739ec0ec476d0"
- integrity sha512-1w0pZtceaUdfAnxMSCGHCQalhi+mR1jOe76sXzyAXpcPz/Lf0zHSdcGK/U2XpZlnQgQtBZW+d+QBnnzVQKCxAA==
+ version "6.1.21"
+ resolved "https://registry.yarnpkg.com/@fullcalendar/react/-/react-6.1.21.tgz#6f396ab7460d3ad9d07f4c32b1ac483b9b21120f"
+ integrity sha512-TLpmGUd5k/PMdCh8XbeFC9PW9wuGvMms1oCxWgXyjK3EFPXAAd0PLfcvwKdyxoAS5eK1E4RJFkjMHvsYHpimcg==
"@github/webauthn-json@^2.1.1":
version "2.1.1"
@@ -1053,19 +1216,19 @@
"@lingui/core" "5.9.5"
"@mantine/carousel@^9.2.1":
- version "9.2.1"
- resolved "https://registry.yarnpkg.com/@mantine/carousel/-/carousel-9.2.1.tgz#bc470ae1c2801d66b40de9d1e76eee869995fb1c"
- integrity sha512-b0ZBDnKhzztEFWNWbbFpPMqaV/4k/lclX8KB0PfU+qhu3Fa6wjS1VIn4XLZu9N3vgkzPkNXwDzpcwFShA9Uvqw==
+ version "9.3.2"
+ resolved "https://registry.yarnpkg.com/@mantine/carousel/-/carousel-9.3.2.tgz#1044f49a416e7c0ab89bd43ed8bd1bdf487ecd4c"
+ integrity sha512-eQAmaeB2xHYEhNnGwKqtqlInnGgcrQATe310GdD1wL7JXuAoYJswdFqlMXXgGPNfrx6wxf1JsIay/mIlHvs4eQ==
"@mantine/charts@^9.2.1":
- version "9.2.1"
- resolved "https://registry.yarnpkg.com/@mantine/charts/-/charts-9.2.1.tgz#64811e07c1094b2b9bc67f04230e5dcebfe76be1"
- integrity sha512-AVP0VEfcsbWwLBeU8rbEsN2gz3GebQECTreRq5AJ0Z5V1eWmTO7XFkRP9C5C6oHnkY4Vppa1x8cRYgyTsc/YbQ==
+ version "9.3.2"
+ resolved "https://registry.yarnpkg.com/@mantine/charts/-/charts-9.3.2.tgz#4d4842875a17da3004cf8e34e9c66fecdf13913c"
+ integrity sha512-G3cFLLxmmRr0ij5fOHeO/jqR/U+DnMNZy0S7GEvs4lIzDRl871TDb1BogZyeHUGKuLnsLBYpTA719IcmswYGMw==
"@mantine/core@^9.2.1":
- version "9.2.1"
- resolved "https://registry.yarnpkg.com/@mantine/core/-/core-9.2.1.tgz#6bed4beac0b8c5f385f8923e4f158eb7472b633d"
- integrity sha512-CicPg9i2dM2pGp1jj+dMiR/63OFDsPjgJke4v5+0nbfJ+C7gn4C+7ltrp4RIETDMZHcj0fFuDRG0qtbiyBxvWA==
+ version "9.3.2"
+ resolved "https://registry.yarnpkg.com/@mantine/core/-/core-9.3.2.tgz#cb23bea516281d96ad86e543827580a84820ce05"
+ integrity sha512-Upy/Z9Sj2eW2dGrFgUy/2kISVsxMTBYTDfP2TFdsIA3PdPSBkdqfSOPX/ug3d3F3a4bnwQSqcO6+aPEpBIh8dg==
dependencies:
"@floating-ui/react" "^0.27.19"
clsx "^2.1.1"
@@ -1074,62 +1237,62 @@
type-fest "^5.6.0"
"@mantine/dates@^9.2.1":
- version "9.2.1"
- resolved "https://registry.yarnpkg.com/@mantine/dates/-/dates-9.2.1.tgz#47c9eb8a854a7f1e6fa3993e9966babb793e9e4a"
- integrity sha512-cyRC8bnZ6W+SzQf/RM+/eDeWhZTZF148z+OcgqiERdkAujh0q88Ddybv/Hshv1EOf0rCe6oiHSZWxIxmUf7KAg==
+ version "9.3.2"
+ resolved "https://registry.yarnpkg.com/@mantine/dates/-/dates-9.3.2.tgz#6dda1854fe97631348cea7e1cc1d4380041bf14b"
+ integrity sha512-MzHrXGoOb3rCnHBlsI/BPAjC8K5tZ4f8pzg66tsTsupVCQBaBpHSVatQwNRJ6K2JC9pyCyTa9BL803C8AiWycA==
dependencies:
clsx "^2.1.1"
"@mantine/dropzone@^9.2.1":
- version "9.2.1"
- resolved "https://registry.yarnpkg.com/@mantine/dropzone/-/dropzone-9.2.1.tgz#3003d745da2f08246fc055137d250beb4f743283"
- integrity sha512-rgebEz2bUubqA5jQpsh0SZ9/4DJFnUSF+a4p8uzAVlgNfo6aU/r+I4lEsD8gzLKuxrfN0TgkwR1qmAjLWIy0yQ==
+ version "9.3.2"
+ resolved "https://registry.yarnpkg.com/@mantine/dropzone/-/dropzone-9.3.2.tgz#884131edba1644d1a515e4cfe0af8098eabd5baf"
+ integrity sha512-wx/6wSVLVW+OfPU9FgkMkfnaUd7roPZG1zOlzE6EIRYIqsHciY3OAlrhQDpYnTkowsseJpXDg4JG788l5kNDUQ==
dependencies:
react-dropzone "15.0.0"
"@mantine/form@^9.2.1":
- version "9.2.1"
- resolved "https://registry.yarnpkg.com/@mantine/form/-/form-9.2.1.tgz#f75d82a16d82a1aa3105ff86328a032b6ff712bb"
- integrity sha512-PV0dcbmsKhZkn3Ryztqp8Kb1N16v2nWXO71p4utTmN7E/lHWHO1ccj7Y72sIteWJo1YeNHzzkssaYRSnxgOvYA==
+ version "9.3.2"
+ resolved "https://registry.yarnpkg.com/@mantine/form/-/form-9.3.2.tgz#4aed07aa4aae09fa96921101bde1892fcfbf120f"
+ integrity sha512-jWEXcx8hhddOsny+q/lFtVToNS3VBJYICrkfFMWJsN+WAZamnPItWTPLqulTYVp1T8uma9MsEZ1LX4kqWUFANA==
dependencies:
"@standard-schema/spec" "^1.1.0"
fast-deep-equal "^3.1.3"
klona "^2.0.6"
"@mantine/hooks@^9.2.1":
- version "9.2.1"
- resolved "https://registry.yarnpkg.com/@mantine/hooks/-/hooks-9.2.1.tgz#8f81303b5eab68b10f4b3d7c99795b70932bc2db"
- integrity sha512-IX/ztVG9eWmQTRsN7G8odyW4JckNvN8qv5A2ULzXyazjtAKLuaUpuMz0c6XhRp10J0g4bVfV3rhrTgWeImqxqg==
+ version "9.3.2"
+ resolved "https://registry.yarnpkg.com/@mantine/hooks/-/hooks-9.3.2.tgz#1a53767d3d2ec983c105498bf4e3805f08d1ddc3"
+ integrity sha512-jOjpUe0x1A/k3XUiu2/aaSCasXRI5ZKZOucm3ypwsvm9F2u8C1xzwBvagrzlbNZwJRF5vNYIJtCaT7NunPyc0A==
"@mantine/modals@^9.2.1":
- version "9.2.1"
- resolved "https://registry.yarnpkg.com/@mantine/modals/-/modals-9.2.1.tgz#257c09088372b38848fb08beeb1124ed3fbe63b3"
- integrity sha512-YvZ85ZtMg6arFserkmmP18gJRD9ztLLT3vz8UrkwCdVwTGGr14X93hhS0UtR5X96ANXUzC8fU/S2ncQmNqw+NQ==
+ version "9.3.2"
+ resolved "https://registry.yarnpkg.com/@mantine/modals/-/modals-9.3.2.tgz#d0c4e8d21bb5224230272cfdb2888dd63917420a"
+ integrity sha512-XorW2PcYU+DQQVZmY80OlwI/bgkBPzf9MscjEZep8Z3aowrlNpnJXFbu2RoPCPMwROU2nX4gt0HJP2OiuGr28A==
"@mantine/notifications@^9.2.1":
- version "9.2.1"
- resolved "https://registry.yarnpkg.com/@mantine/notifications/-/notifications-9.2.1.tgz#de99ed4fc64e05024cb5a66e2d619a248ac2e042"
- integrity sha512-H6lSsKUPdWPYcXFeOcqqcegUl72Iua9yD369s/gchfDvI+PrL4IM5UuWNHTeABJ1eb9FbTOw8B5RDSMZjTZNSA==
+ version "9.3.2"
+ resolved "https://registry.yarnpkg.com/@mantine/notifications/-/notifications-9.3.2.tgz#c608bb5af801c7091f9eb2c15be51d1ec8251363"
+ integrity sha512-mnda8hE/DizPi5Bbiwd2M2jXxfSZSUeayvnLYMbFweGQKXM+QRmX1ootyDRVqWew8paltewTNp84cWLjj/6fKw==
dependencies:
- "@mantine/store" "9.2.1"
+ "@mantine/store" "9.3.2"
react-transition-group "4.4.5"
"@mantine/spotlight@^9.2.1":
- version "9.2.1"
- resolved "https://registry.yarnpkg.com/@mantine/spotlight/-/spotlight-9.2.1.tgz#4157cef5a9a1b9ac5f6025b57435a8dc484b58b9"
- integrity sha512-D6/BJ8/ftUBwiSFGTtYUM/LqlBk40XZqZFlmEFRM8chDPzEId1O+5FU7mj8KapPR9zRgoAcdT4LMI6JaLp0c0A==
+ version "9.3.2"
+ resolved "https://registry.yarnpkg.com/@mantine/spotlight/-/spotlight-9.3.2.tgz#3cab5fe280b1612577b8d0b18314ff287873e7ff"
+ integrity sha512-JAJhW51qvYNiPTEnX9ewZX521gKDsVsmaecuuR2iNyk0NbrOPB5SWF9ZZrPSMwFVtqnqYHziq5BLukzlf+kG/Q==
dependencies:
- "@mantine/store" "9.2.1"
+ "@mantine/store" "9.3.2"
-"@mantine/store@9.2.1":
- version "9.2.1"
- resolved "https://registry.yarnpkg.com/@mantine/store/-/store-9.2.1.tgz#27a3548c4cc1567baa2613490d7dcb9300b391ba"
- integrity sha512-sBTHt9ilfSZAeXQlqFkm8nRm22RunhevxuOUtdSwS9HhuMuS8T27dRRgbdKH2oEFUbaccdQSy5bHbmGbEgVO8w==
+"@mantine/store@9.3.2":
+ version "9.3.2"
+ resolved "https://registry.yarnpkg.com/@mantine/store/-/store-9.3.2.tgz#2b878741b04147fdaecb40fed0c157eefde95e3b"
+ integrity sha512-uNmvjkwfUHZJ5bvzQroLFvubuUAHjBM0rh69RBRsUCG5FR5K4f8y4SX8+lch0wS6UJuuvodsSIK8H5jvZuFSgQ==
"@mantine/vanilla-extract@^9.2.1":
- version "9.2.1"
- resolved "https://registry.yarnpkg.com/@mantine/vanilla-extract/-/vanilla-extract-9.2.1.tgz#ba86032eaaf278153d3dd110c8e4327457cc0606"
- integrity sha512-5cNesX5kdmClWCMFqxDIVZF2JRCne2OrIj5UE3tuyGJAY3IGkchBnAf/bEx3c5QDSXxq4+6y97hs5gQBgODePA==
+ version "9.3.2"
+ resolved "https://registry.yarnpkg.com/@mantine/vanilla-extract/-/vanilla-extract-9.3.2.tgz#0ac3e777a1dbf30385929f26c702447b0906d714"
+ integrity sha512-e4m1hmdfAHqm8XF4jwU4b2UnuwTPcnVG7r8KM7B8i+A3d19rRTeWt7+wv10628RcYzU71eM0tk3zt3Iop77KWQ==
"@marijn/find-cluster-break@^1.0.0":
version "1.0.2"
@@ -1234,11 +1397,11 @@
"@octokit/openapi-types" "^27.0.0"
"@playwright/test@^1.60.0":
- version "1.60.0"
- resolved "https://registry.yarnpkg.com/@playwright/test/-/test-1.60.0.tgz#e696c31427e8882851235cd556dc2490c3206d97"
- integrity sha512-O71yZIbAh/PxDMNGns37GHBIfrVkEVyn+AXyIa5dOTfb4/xNvRWV+Vv/NMbNCtODB/pO7vLlF2OTmMVLhmr7Ag==
+ version "1.61.0"
+ resolved "https://registry.yarnpkg.com/@playwright/test/-/test-1.61.0.tgz#dcc3d43e581aab2985d70413309d89350e980ad8"
+ integrity sha512-cKA5B6lpFEMyMGjxF54QihfYpB4FkEGH+qZhtArDEG+wezQAJY8Pq6C7T1SjWz+FFzt3TbyoXBQYk/0292TdJA==
dependencies:
- playwright "1.60.0"
+ playwright "1.61.0"
"@reduxjs/toolkit@^1.9.0 || 2.x.x":
version "2.12.0"
@@ -1396,59 +1559,59 @@
resolved "https://registry.yarnpkg.com/@rollup/rollup-win32-x64-msvc/-/rollup-win32-x64-msvc-4.62.2.tgz#3671ce3f9b928d5c01f879792d5c0b60ae14d4ad"
integrity sha512-BfzEnDJOt9T8M989/lA37EcJgat01wLRnoi5dQf3QzOH7jzpqTAzdDbVfRljVr5r+jzKqpbHeyOfAaXxAd0PAA==
-"@sentry-internal/browser-utils@10.57.0":
- version "10.57.0"
- resolved "https://registry.yarnpkg.com/@sentry-internal/browser-utils/-/browser-utils-10.57.0.tgz#5bda27f6ded3529afbc764195443335a9e08f9da"
- integrity sha512-tXObp954rMTSYKlbftjVXHtNl4t/6ssks3jkqyzmKb+PDPWzabGQO7sWwqVuTjT8Kx/8A3FmriS1bGmqxiJy3A==
+"@sentry/browser-utils@10.58.0":
+ version "10.58.0"
+ resolved "https://registry.yarnpkg.com/@sentry/browser-utils/-/browser-utils-10.58.0.tgz#e5d17e78f54ecd9c671c312b8ac0823b92e9c98b"
+ integrity sha512-TzXrhZq3Llj6qPSv0ZVG5N5c7C6qNN/aRKJXhq2LombJrLwiQrWdgizp7zdHA0FGlZ7F5YpyRA2JIpkhvrFqYA==
dependencies:
- "@sentry/core" "10.57.0"
+ "@sentry/core" "10.58.0"
-"@sentry-internal/feedback@10.57.0":
- version "10.57.0"
- resolved "https://registry.yarnpkg.com/@sentry-internal/feedback/-/feedback-10.57.0.tgz#846b9c424208f9ebe798c8abb2c0f4272cfc3c1d"
- integrity sha512-ZcF4QhkqGX3iiQSXB2N0N3Awp+j5iqnDRu6PA/qyLFrWqH5ZiiAAgu59OLD9E6XAdg6iFtLYw19MAMZVK8qNOQ==
+"@sentry/browser@10.58.0":
+ version "10.58.0"
+ resolved "https://registry.yarnpkg.com/@sentry/browser/-/browser-10.58.0.tgz#bd6243c9b3c20d4d04eecc0623237b05c723e344"
+ integrity sha512-Syf6h6HDwC15fk86+/0ql8ebwwJFw2wp+lvOX9GfLTJVOqrSILCrtLKNI+f4v/3w8mzImsv9ttJGGbUugLNvcA==
dependencies:
- "@sentry/core" "10.57.0"
+ "@sentry/browser-utils" "10.58.0"
+ "@sentry/core" "10.58.0"
+ "@sentry/feedback" "10.58.0"
+ "@sentry/replay" "10.58.0"
+ "@sentry/replay-canvas" "10.58.0"
-"@sentry-internal/replay-canvas@10.57.0":
- version "10.57.0"
- resolved "https://registry.yarnpkg.com/@sentry-internal/replay-canvas/-/replay-canvas-10.57.0.tgz#4c0fa99628872fd2db6d6da0f63979642c2faa05"
- integrity sha512-zsfa4JcfV0AEc9YhNxNabd5lSZL2Av84saAyexGAqcHs+67m9Gd0cGStOzMb/nCl7UAtmdP0aI+G7a3rcxxN/A==
+"@sentry/core@10.58.0":
+ version "10.58.0"
+ resolved "https://registry.yarnpkg.com/@sentry/core/-/core-10.58.0.tgz#66180ae40b341b352e3932753d5eb71157a00d0e"
+ integrity sha512-bkIbh2c6dzwhrWn/FGWu7j8hf6TAat2XxpkGM91LiN09fLYUXIMwcohVsXqze5l2cq35TnvqmSROAbRNr27GVw==
+
+"@sentry/feedback@10.58.0":
+ version "10.58.0"
+ resolved "https://registry.yarnpkg.com/@sentry/feedback/-/feedback-10.58.0.tgz#7d74a2750433c5e6420f1804c5deaf2f6cd71d63"
+ integrity sha512-VmIlR/0O0GXITbvgjPkQqd6yM0JDEk52WXv6Rs1kTdaIDU5h3Y64VDVN4MAbYVRHqSz7F1arjRRk2FkaKC7ZOQ==
dependencies:
- "@sentry-internal/replay" "10.57.0"
- "@sentry/core" "10.57.0"
-
-"@sentry-internal/replay@10.57.0":
- version "10.57.0"
- resolved "https://registry.yarnpkg.com/@sentry-internal/replay/-/replay-10.57.0.tgz#729e528d95a5314e0cb54e8e646143816e192a78"
- integrity sha512-Wmnx/6ABynVH1iwuoNUqJNyjIUqsqoGML7qsyivBRKb5Wo2YQtPOQlQYfxfZSvWzGpcoSVdInkRjDssUQxQEQg==
- dependencies:
- "@sentry-internal/browser-utils" "10.57.0"
- "@sentry/core" "10.57.0"
-
-"@sentry/browser@10.57.0":
- version "10.57.0"
- resolved "https://registry.yarnpkg.com/@sentry/browser/-/browser-10.57.0.tgz#89d95bff41b6b2652a93f8caa9d6c2bc7b73e48e"
- integrity sha512-s36AQy/CKXTfyY9Z+qUhzNomntZXgfs0rbaK7q9ffnFkqcPwzE8qQtVs58y3Suut56u+AhwSztgQtERcuZ5VIA==
- dependencies:
- "@sentry-internal/browser-utils" "10.57.0"
- "@sentry-internal/feedback" "10.57.0"
- "@sentry-internal/replay" "10.57.0"
- "@sentry-internal/replay-canvas" "10.57.0"
- "@sentry/core" "10.57.0"
-
-"@sentry/core@10.57.0":
- version "10.57.0"
- resolved "https://registry.yarnpkg.com/@sentry/core/-/core-10.57.0.tgz#bda587a82f364ae9dc0be2aa06e721aea8502d05"
- integrity sha512-kntItTA2kiT0YpL7encXaF6mkdZMB+y48lwj8w1wkfBpfJAC7sifdgrzLQZqmsqVNE3crg9VfufaAGA+78uFMg==
+ "@sentry/core" "10.58.0"
"@sentry/react@^10.57.0":
- version "10.57.0"
- resolved "https://registry.yarnpkg.com/@sentry/react/-/react-10.57.0.tgz#5c0e7e42f332b1b39ea4255ce1a9dbefb348c6bd"
- integrity sha512-6QThwQ4XWQ2rwKZEVQ9P9WKl7JlowC7S5LpAvmMdrwlfJBpLDFOsM7tycnIvbXTXf0ZOOuLFPa4L4YYbdyNGmA==
+ version "10.58.0"
+ resolved "https://registry.yarnpkg.com/@sentry/react/-/react-10.58.0.tgz#f53a4e3aa36f7ed13a8fac6334c0aee081cea254"
+ integrity sha512-3FLRtnXrue30UZALrQ9wQZeuvVmZl/pTCA+RyPlaZ5GxcYTapN9CVbm1IvbQpK4w1bt80+JxaKM4HikvII6KpA==
dependencies:
- "@sentry/browser" "10.57.0"
- "@sentry/core" "10.57.0"
+ "@sentry/browser" "10.58.0"
+ "@sentry/core" "10.58.0"
+
+"@sentry/replay-canvas@10.58.0":
+ version "10.58.0"
+ resolved "https://registry.yarnpkg.com/@sentry/replay-canvas/-/replay-canvas-10.58.0.tgz#a1ce955549738e815f2ffba5f4b86eb692ca98ba"
+ integrity sha512-ufFmaJ968DXGe6u9W/UqNVjCCTtAqT2bNtSu1jHAjIFFpWIuM80lcR33grK6SuGnFxceu5iJFaIW6JRyfbM0Sw==
+ dependencies:
+ "@sentry/core" "10.58.0"
+ "@sentry/replay" "10.58.0"
+
+"@sentry/replay@10.58.0":
+ version "10.58.0"
+ resolved "https://registry.yarnpkg.com/@sentry/replay/-/replay-10.58.0.tgz#347eb26b86a458065172d880dc953d5a049eab42"
+ integrity sha512-EVasQNUenpwJksK9DI1TQ78YytpjLAhxn0UTiHqA3sU/s1fHK5XZdZJPr/9uEGedRoInIP0UIWmbOtOEX8HHDg==
+ dependencies:
+ "@sentry/browser-utils" "10.58.0"
+ "@sentry/core" "10.58.0"
"@sinclair/typebox@^0.27.8":
version "0.27.10"
@@ -1585,6 +1748,11 @@
resolved "https://registry.yarnpkg.com/@types/estree/-/estree-1.0.9.tgz#cf3f0e876d7bee15a93ab925b82bf570a3904a24"
integrity sha512-GhdPgy1el4/ImP05X05Uw4cw2/M93BCUmnEvWZNStlCzEKME4Fkk+YpoA5OiHNQmoS7Cafb8Xa3Pya8m1Qrzeg==
+"@types/gensync@^1.0.5":
+ version "1.0.5"
+ resolved "https://registry.yarnpkg.com/@types/gensync/-/gensync-1.0.5.tgz#1819eba537d036dcf4ec7e8c8f15fbfe938e99a0"
+ integrity sha512-MbsRCT7mTikHwKZ0X+LVUTLRrZZRLipTuXEO9qOYO+zmjMVk81axyClMROf6uoPD9MRVu46bx8zoR0Ad9q3NAg==
+
"@types/history@^4.7.11":
version "4.7.11"
resolved "https://registry.yarnpkg.com/@types/history/-/history-4.7.11.tgz#56588b17ae8f50c53983a524fc3cc47437969d64"
@@ -1609,15 +1777,20 @@
dependencies:
"@types/istanbul-lib-report" "*"
+"@types/jsesc@^2.5.0":
+ version "2.5.1"
+ resolved "https://registry.yarnpkg.com/@types/jsesc/-/jsesc-2.5.1.tgz#c34defc608ec94b68dc6a12a581b440942c6d503"
+ integrity sha512-9VN+6yxLOPLOav+7PwjZbxiID2bVaeq0ED4qSQmdQTdjnXJSaCVKTR58t15oqH1H5t8Ng2ZX1SabJVoN9Q34bw==
+
"@types/marked@^4.0.7":
version "4.3.2"
resolved "https://registry.yarnpkg.com/@types/marked/-/marked-4.3.2.tgz#e2e0ad02ebf5626bd215c5bae2aff6aff0ce9eac"
integrity sha512-a79Yc3TOk6dGdituy8hmTTJXjOkZ7zsFYV10L337ttq/rec8lRMDBpV7fL3uLx6TgbFCa5DU/h8FmIBQPSbU0w==
"@types/node@*", "@types/node@^25.9.2":
- version "25.9.2"
- resolved "https://registry.yarnpkg.com/@types/node/-/node-25.9.2.tgz#fc8958e757994b71fee516f9634bdb03d1b19e9f"
- integrity sha512-G05zqtJhcDLb8uslf5EjCxXg9G1KQxiV8OS0R26IC//Eoyitzqe8z37I7cqvnZlrlSfgocQRfSn/AHBZJJFyGw==
+ version "25.9.3"
+ resolved "https://registry.yarnpkg.com/@types/node/-/node-25.9.3.tgz#11dfe7a33e68fa5c560f0aa76cc5595621ef26b9"
+ integrity sha512-603BddQMv3pUcr4U2dhujk83N2tTDVr/34wII2B6bJy6g+8WD6yUb11jszNs0gdi4PesVWl7ABt8nYMVpnLUcg==
dependencies:
undici-types ">=7.24.0 <7.24.7"
@@ -1821,7 +1994,7 @@
"@vanilla-extract/compiler" "^0.7.0"
"@vanilla-extract/integration" "^8.0.9"
-"@vitejs/plugin-react@^5.2.0":
+"@vitejs/plugin-react@^5":
version "5.2.0"
resolved "https://registry.yarnpkg.com/@vitejs/plugin-react/-/plugin-react-5.2.0.tgz#108bd0f566f288ce3566982df4eff137ded7b15f"
integrity sha512-YmKkfhOAi3wsB1PhJq5Scj3GXMn3WvtQ/JC0xoopuHoXSdmtdStOpFrYaT1kie2YgFBcIe64ROzMYRjCrYOdYw==
@@ -2494,6 +2667,11 @@ emoji-regex@^8.0.0:
resolved "https://registry.yarnpkg.com/emoji-regex/-/emoji-regex-8.0.0.tgz#e818fd69ce5ccfcb404594f842963bf53164cc37"
integrity sha512-MSjYzcWNOA0ewAHpz0MxpYFvwg6yjy1NG3xteoqz644VCo/RPgnr1/GGt+ic3iJTzQ8Eu3TdM14SawnVUmGE6A==
+empathic@^2.0.1:
+ version "2.0.1"
+ resolved "https://registry.yarnpkg.com/empathic/-/empathic-2.0.1.tgz#37b1bede31093e04a03d2abce95ea323fee8ef49"
+ integrity sha512-YGRs8knHhKHVShLkFET/rWAU8kmHbOV5LwN938RHI0pljAJ1Gf6SzXsSmRaEzcXTtOOmVqJ5+WtQPL5uigY50Q==
+
error-ex@^1.3.1:
version "1.3.4"
resolved "https://registry.yarnpkg.com/error-ex/-/error-ex-1.3.4.tgz#b3a8d8bb6f92eecc1629e3e27d3c8607a8a32414"
@@ -2919,6 +3097,11 @@ import-fresh@^3.2.1, import-fresh@^3.3.0:
parent-module "^1.0.0"
resolve-from "^4.0.0"
+import-meta-resolve@^4.2.0:
+ version "4.2.0"
+ resolved "https://registry.yarnpkg.com/import-meta-resolve/-/import-meta-resolve-4.2.0.tgz#08cb85b5bd37ecc8eb1e0f670dc2767002d43734"
+ integrity sha512-Iqv2fzaTQN28s/FwZAoFq0ZSs/7hMAHJVX+w8PZl3cY19Pxk6jFFalxQoIfW2826i/fDLXv8IiEZRIT0lDuWcg==
+
imurmurhash@^0.1.4:
version "0.1.4"
resolved "https://registry.yarnpkg.com/imurmurhash/-/imurmurhash-0.1.4.tgz#9218b9b2b928a238b13dc4fb6b6d576f231453ea"
@@ -3119,6 +3302,11 @@ js-sha256@^0.10.1:
resolved "https://registry.yarnpkg.com/js-sha256/-/js-sha256-0.10.1.tgz#b40104ba1368e823fdd5f41b66b104b15a0da60d"
integrity sha512-5obBtsz9301ULlsgggLg542s/jqtddfOpV5KJc4hajc9JV8GeY2gZHSVpYBn4nWqAUTJ9v+xwtbJ1mIBgIH5Vw==
+js-tokens@^10.0.0:
+ version "10.0.0"
+ resolved "https://registry.yarnpkg.com/js-tokens/-/js-tokens-10.0.0.tgz#dffe7599b4a8bb7fe30aff8d0235234dffb79831"
+ integrity sha512-lM/UBzQmfJRo9ABXbPWemivdCW8V2G8FHaHdypQaIy523snUjog0W71ayWXTjiR+ixeMyVHN2XcpnTd/liPg/Q==
+
"js-tokens@^3.0.0 || ^4.0.0", js-tokens@^4.0.0:
version "4.0.0"
resolved "https://registry.yarnpkg.com/js-tokens/-/js-tokens-4.0.0.tgz#19203fb59991df98e3a287050d4647cdeaf32499"
@@ -3274,14 +3462,14 @@ make-dir@^4.0.0:
semver "^7.5.3"
mantine-contextmenu@^9.2.1:
- version "9.2.1"
- resolved "https://registry.yarnpkg.com/mantine-contextmenu/-/mantine-contextmenu-9.2.1.tgz#d1d4dab0ca1eeaba7f1bba6cf2cad8cf31636709"
- integrity sha512-oqFPT9qOQBPgf2eSuiujGQp38QgV0WsIIMxQkPfkjVc8FWAKcnXv7OGxGN1ctRrcMqUbsS34rjI0SvNdmFwG8A==
+ version "9.3.0"
+ resolved "https://registry.yarnpkg.com/mantine-contextmenu/-/mantine-contextmenu-9.3.0.tgz#e32348f79a3eb1a75778d84e3f3d3b5835510a0e"
+ integrity sha512-8Uy9eK9aTP/ba6VpLgMMjhOV6WI0Ye2AB6MwsaJTNWR82IkxzS3mx89UuG0xtNvVh2KH7xPiM598f/PIzmiXuQ==
mantine-datatable@^9.2.2:
- version "9.2.2"
- resolved "https://registry.yarnpkg.com/mantine-datatable/-/mantine-datatable-9.2.2.tgz#2b1238ac8b115d2c76e6b3646b425a626d92fed4"
- integrity sha512-pSWIAggUQC1I4lNUzwVoNm85CIkx8jst0syzRo8N9CrTHdc+Z2+8aFLfBniSHbF4nJyLE6nkeAcb8uvFdHbVfw==
+ version "9.3.0"
+ resolved "https://registry.yarnpkg.com/mantine-datatable/-/mantine-datatable-9.3.0.tgz#32cd4ca52d30aa3340a7f2e406d84809cfc62910"
+ integrity sha512-YCLC5VCRPUHDoDUvWgVY81bx17MDk3Gz38icOINe/QO2ZKASGxNzf/wiqV3Dv1N/BRO601GyVMHRH6LzFWVC7g==
marked@^4.1.0:
version "4.3.0"
@@ -3639,17 +3827,17 @@ pkg-types@^2.3.0:
exsolve "^1.0.8"
pathe "^2.0.3"
-playwright-core@1.60.0:
- version "1.60.0"
- resolved "https://registry.yarnpkg.com/playwright-core/-/playwright-core-1.60.0.tgz#24e0d9cc4730713db5dffcace29b5e4696b1907a"
- integrity sha512-9bW6zvX/m0lEbgTKJ6YppOKx8H3VOPBMOCFh2irXFOT4BbHgrx5hPjwJYLT40Lu+4qtD36qKc/Hn56StUW57IA==
+playwright-core@1.61.0:
+ version "1.61.0"
+ resolved "https://registry.yarnpkg.com/playwright-core/-/playwright-core-1.61.0.tgz#caf8078b2a39cd7738dc75ec11cb3b47f385c3f0"
+ integrity sha512-caX7TrY3Ml6egyDX0WUcTHDxodl/b51y5wJOdCEA36QviK/s2g081hvmGs8eaE3DWb6NYZQ6BjO/QkNRPenoPA==
-playwright@1.60.0:
- version "1.60.0"
- resolved "https://registry.yarnpkg.com/playwright/-/playwright-1.60.0.tgz#89710863a51f21112633ef8b6b182594d3bfd7b5"
- integrity sha512-hheHdokM8cdqCb0lcE3s+zT4t4W+vvjpGxsZlDnikarzx8tSzMebh3UiFtgqwFwnTnjYQcsyMF8ei2mCO/tpeA==
+playwright@1.61.0:
+ version "1.61.0"
+ resolved "https://registry.yarnpkg.com/playwright/-/playwright-1.61.0.tgz#7082df3df08ffa82b11420ea5fae84a40bd16e3f"
+ integrity sha512-Z+7BeeqQPRRzklHsVFP4KTGIyMxKUmfeRA4WisM6G3/XW6nwGeX6fX9qYaDa+CiUqpOkb2f6X3nar05R3kSuJQ==
dependencies:
- playwright-core "1.60.0"
+ playwright-core "1.61.0"
optionalDependencies:
fsevents "2.3.2"
@@ -3775,9 +3963,9 @@ react-grid-layout@1.4.4:
resize-observer-polyfill "^1.5.1"
react-hook-form@^7.78.0:
- version "7.78.0"
- resolved "https://registry.yarnpkg.com/react-hook-form/-/react-hook-form-7.78.0.tgz#b5a7d496d9077a71f36c8f2cacd3990464af2643"
- integrity sha512-EEZqc+N23moyzTlz61Pj+JvcXo76ICkpfOZo8JZw+sM4+wLQGh6nI2Ms+PdMOYNluFu0ghlM7B8mCzhRYtJCnA==
+ version "7.79.0"
+ resolved "https://registry.yarnpkg.com/react-hook-form/-/react-hook-form-7.79.0.tgz#dc965ecb161e67ea91ee46f00d870ea35871b26a"
+ integrity sha512-mhYp/MTmXvzYX6AJcJVko0rktoIhhmRnEouObj4wF5i/tCttgJvnp1+9wRkpITZjDTqpo4IOSJqu0dBlPlV/Lw==
react-is@^16.13.1, react-is@^16.7.0:
version "16.13.1"
@@ -4086,10 +4274,10 @@ semver@^6.0.0, semver@^6.3.1:
resolved "https://registry.yarnpkg.com/semver/-/semver-6.3.1.tgz#556d2ef8689146e46dcea4bfdd095f3434dffcb4"
integrity sha512-BR7VvDCVHO+q2xBEWskxS6DJE1qRnb7DxzUrogb71CWoSficBxYsiAGd+Kl0mmq/MprG9yArRkyrQxTO6XjMzA==
-semver@^7.5.3, semver@^7.5.4:
- version "7.8.4"
- resolved "https://registry.yarnpkg.com/semver/-/semver-7.8.4.tgz#c73eceebae0616934be8dff28a7fd70757c8e696"
- integrity sha512-rUCObTnP32Q08R2uuIrt7r9PlEonuTmtuXYcW6s5kjdlj3xbnwe+21yXptAUYcMAABLkYYTtnmzb3w3EDZfueA==
+semver@^7.5.3, semver@^7.5.4, semver@^7.7.3:
+ version "7.8.5"
+ resolved "https://registry.yarnpkg.com/semver/-/semver-7.8.5.tgz#39b646037dd50c14fb451e7e4cac58ed8b863f69"
+ integrity sha512-Y7/KDsb8LjooZpwaqGyulO6DQlksgCncchHGk+sZIY4SBvUocMBEFH5Ur1fI4dV+Jvl0w6cjvucaIi40puRioA==
set-blocking@^2.0.0:
version "2.0.0"
diff --git a/src/frontend/tests/pui_plugins.spec.ts b/src/frontend/tests/pui_plugins.spec.ts
index 210be09a2b..e00435a0a9 100644
--- a/src/frontend/tests/pui_plugins.spec.ts
+++ b/src/frontend/tests/pui_plugins.spec.ts
@@ -75,8 +75,8 @@ test('Plugins - User Settings', async ({ browser }) => {
await navigate(page, 'settings/user/');
await loadTab(page, 'Plugin Settings');
- // User settings for the "Sample Plugin" should be visible
- await page.getByRole('button', { name: 'Sample Plugin' }).click();
+ // User settings for the "SampleIntegrationPlugin" should be visible
+ await page.getByRole('button', { name: 'SampleIntegrationPlugin' }).click();
await page.getByText('User Setting 1').waitFor();
await page.getByText('User Setting 2').waitFor();